==> nextcloud-25.0.5.tgz: nextcloud/apps/twofactor_backupcodes/l10n/bg.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Създадохте резервен код за двустепенното удостоверяване за вашия профил",
    "Second-factor backup codes" : "Резервен код за втората стъпка",
    "Generate backup codes" : "Генериране на резервни кодове",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Активирали сте двустепенно удостоверяване, но все още не сте генерирали резервни кодове. Те са необходими за възстановяване на достъп до вашия профил, в случай че загубите втората си стъпка.",
    "Backup code" : "Резервен код",
    "Use backup code" : "Използвай код за възстановяване",
    "Two factor backup codes" : "Двустепенни резервни кодове",
    "A two-factor auth backup codes provider" : "Доставчик на двустепенни резервни кодове за удостоверяване",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Резервен код е бил генериран. Използвани са {used} от {total} кода.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Това е вашия резервен код. Моля, запишете го (или го принтирайте) защото по-късно няма да имате възможност да го видите.",
    "Save backup codes" : "Записване на резервния код",
    "Print backup codes" : "Принтиране на резервния код",
    "Regenerate backup codes" : "Регенериране на резервния код",
    "If you regenerate backup codes, you automatically invalidate old codes." : "При регенерирането на резервния код, стария код автоматично бива анулиран.",
    "An error occurred while generating your backup codes" : "Възникна грешка при генерирането на резервния код",
    "{name} backup codes" : "{name} резервни кодове",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Използвайте един от резервните кодове, които сте запазили, когато настройвате двустепенно удостоверяване.",
    "Submit" : "Изпращане"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_backupcodes/l10n/bg.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Създадохте резервен код за двустепенното удостоверяване за вашия профил",
    "Second-factor backup codes" : "Резервен код за втората стъпка",
    "Generate backup codes" : "Генериране на резервни кодове",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Активирали сте двустепенно удостоверяване, но все още не сте генерирали резервни кодове. Те са необходими за възстановяване на достъп до вашия профил, в случай че загубите втората си стъпка.",
    "Backup code" : "Резервен код",
    "Use backup code" : "Използвай код за възстановяване",
    "Two factor backup codes" : "Двустепенни резервни кодове",
    "A two-factor auth backup codes provider" : "Доставчик на двустепенни резервни кодове за удостоверяване",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Резервен код е бил генериран. Използвани са {used} от {total} кода.",
    "Save backup codes" : "Записване на резервния код",
    "Print backup codes" : "Принтиране на резервния код",
    "Regenerate backup codes" : "Регенериране на резервния код",
    "If you regenerate backup codes, you automatically invalidate old codes." : "При регенерирането на резервния код, стария код автоматично бива анулиран.",
    "An error occurred while generating your backup codes" : "Възникна грешка при генерирането на резервния код",
    "{name} backup codes" : "{name} резервни кодове",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Използвайте един от резервните кодове, които сте запазили, когато настройвате двустепенно удостоверяване.",
    "Submit" : "Изпращане",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Това е вашия резервен код. Моля, запишете го (или го принтирайте) защото по-късно няма да имате възможност да го видите."
},
"nplurals=2; plural=(n != 1);");
